note
	description: "Tests given by instructor to illustrate reference vs. shallow copies."
	author: "Jackie Wang"
	date: "$Date$"
	revision: "$Revision$"

class
	TEST_EQUALITY

inherit
	ES_TEST

create
	make

feature -- Adding tests
	make
		do
			add_boolean_case (agent test_equality_1)
			add_boolean_case (agent test_equality_2)
			add_boolean_case (agent test_equality_3)

			show_browser
			run_espec
		end

feature -- Misc test
	test_equality_1: BOOLEAN
		local
			o1, o2: C1
		do
			comment ("Test default is_equal")
			create o1.make (3, "s")
			create o2.make (3, "s")
			Result := o1 = o2
			check not Result end

			Result := o1.is_equal (o2)
			check not Result end

			-- Since o1 and o2 are the same type,
			-- call the (default) is_equal feature in C2.
			Result := o1 ~ o2
			check not Result end

			-- Just to make the final value of Result true
			-- so that this test passes.
			Result := true
		end

	test_equality_2: BOOLEAN
		local
			o1, o2: C2
		do
			comment ("Test redefined is_equal")
			create o1.make (3, "s")
			create o2.make (3, "s")
			Result := o1 = o2
			check not Result end

			-- Since o1 and o2 are the same type,
			-- call the (redefined) is_equal feature in C2.
			Result := o1.is_equal (o2)
			check Result end

			Result := o1 ~ o2
			check Result end
		end

	test_equality_3: BOOLEAN
		local
			o1: C2
			o2: STRING
		do
			comment ("Test equality between different types of objects")
			create o1.make (3, "s")
			Result := o1 = o2 -- at this point o2 is void
			check not Result end

			-- Result set to false because o1 and o2 are of different types.
			Result := (o1 ~ o2) and (o2 ~ o1)
			check not Result end

			-- Compilation error: o2 is not a C2 object.
--			Result := o1.is_equal (o2)
--			check Result end

			-- Compilatoin error: target o2 is void
--			Result := o2.is_equal (o1)

			o2 := "s"

			-- Compilation error: o2 is not a C2 object.
--			Result := o1.is_equal (o2)

			-- Compilation error: o1 is not a STRING object.
--			Result := o2.is_equal (o1)

			-- Result set to false because o1 and o2 are of different types.
			Result := (o1 ~ o2) and (o2 ~ o1)
			check not Result end

			-- Just to make the final value of Result true
			-- so that this test passes.
			Result := true
		end
end
